aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorST-DDT <[email protected]>2024-12-29 17:17:44 +0100
committerGitHub <[email protected]>2024-12-29 17:17:44 +0100
commit39f76f7f9bf19449e90b6061ff895e9cb9b71780 (patch)
tree4a4783cf4a9c66441763f9804c2e90fc5eb90139 /src
parent637f81bf9035bdcf030c2dfcd1a875de2721ad71 (diff)
downloadfaker-39f76f7f9bf19449e90b6061ff895e9cb9b71780.tar.xz
faker-39f76f7f9bf19449e90b6061ff895e9cb9b71780.zip
docs(image): improve urlPlaceholder alternatives (#3351)
Diffstat (limited to 'src')
-rw-r--r--src/modules/image/index.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/image/index.ts b/src/modules/image/index.ts
index 5013bcb5..2275cbeb 100644
--- a/src/modules/image/index.ts
+++ b/src/modules/image/index.ts
@@ -260,7 +260,7 @@ export class ImageModule extends ModuleBase {
*
* @since 8.0.0
*
* @deprecated The service has bad uptime. Use `url()` or another method instead.
*/
urlPlaceholder(
options: {
@@ -304,7 +304,7 @@ export class ImageModule extends ModuleBase {
): string {
deprecated({
deprecated: 'faker.image.urlPlaceholder()',
- proposed: 'faker.image.url()',
+ proposed: 'faker.image.url() or faker.image.dataUri()',
since: '9.4.0',
until: '10.0.0',
});
@@ -260,7 +260,7 @@ export class ImageModule extends ModuleBase {
* @since 8.0.0
*
- * @deprecated The service has bad uptime. Use `url()` or another method instead.
+ * @deprecated The service has bad uptime. Use `faker.image.url()` or `faker.image.dataUri()` instead.
*/
urlPlaceholder(